import { fileURLToPath, URL } from 'node:url'
import { resolve } from 'node:path'

import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import AutoImport from 'unplugin-auto-import/vite'
import Components from 'unplugin-vue-components/vite'
import { ArcoResolver } from 'unplugin-vue-components/resolvers'
import cssInjectedByJsPlugin from 'vite-plugin-css-injected-by-js'
import mkcert from 'vite-plugin-mkcert'

// https://vitejs.dev/config/
export default defineConfig({
  plugins: [
    vue(),
    AutoImport({ imports: ['vue'], eslintrc: { enabled: true }, resolvers: [ArcoResolver()] }),
    Components({
      resolvers: [ArcoResolver({ resolveIcons: true, sideEffect: true })],
    }),
    cssInjectedByJsPlugin(),
    mkcert(),
  ],
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url)),
    },
  },
  server: {
    open: true,
    host: 'dev.ezijing.com',
    proxy: {
      // '/api/tiangong': {
      //   target: 'https://api.singularity-ai.com',
      //   changeOrigin: true,
      //   rewrite: (path) => path.replace(/^\/api\/tiangong/, ''),
      // },
      // '/api/deepseek': {
      //   target: 'https://api.deepseek.com',
      //   changeOrigin: true,
      //   rewrite: (path) => path.replace(/^\/api\/deepseek/, ''),
      // },
      // '/api/qwen': {
      //   target: 'https://dashscope.aliyuncs.com',
      //   changeOrigin: true,
      //   rewrite: (path) => path.replace(/^\/api\/qwen/, ''),
      // },
      // '/api/qianfan': {
      //   target: 'https://aip.baidubce.com',
      //   changeOrigin: true,
      //   rewrite: (path) => path.replace(/^\/api\/qianfan/, ''),
      // },
      '/api': {
        target: 'https://api.ezijing.com',
        secure: false,
        changeOrigin: true,
      },
    },
  },
  build: {
    lib: {
      entry: resolve(import.meta.dirname, 'src/main.js'),
      name: 'SkyAgent',
      fileName: 'sky-agent',
    },
  },
})
